#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-auth
version:              1.6.11.3
visibility:           public
id:                   yesod-auth-1.6.11.3-IOUGT3cCDSZLfU3pzgHwx5
key:                  yesod-auth-1.6.11.3-IOUGT3cCDSZLfU3pzgHwx5
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Patrick Brisbin
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>

category:             Web, Yesod
abi:                  92f8bc405a0e290b567cc7f6c6dece8e
exposed:              True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore

hidden-modules:       Yesod.Auth.Routes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-auth
hs-libraries:         HSyesod-auth-1.6.11.3-IOUGT3cCDSZLfU3pzgHwx5
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    attoparsec-aeson-2.2.2.0-3K5rvkmbaC6GALCK495q1W
    authenticate-1.3.5.2-LxwG6trfhuL7FzyXbHJ7aa base-4.18.2.1
    base16-bytestring-1.0.2.0-KkKTvweYtUjAEl7m2QLWFY
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe binary-0.8.9.1
    blaze-builder-0.4.4.1-CVV6q4pVvXFBczRCmYuxry
    blaze-html-0.9.2.0-FHozDOQfWbTE40Bgc3es6n
    blaze-markup-0.8.3.0-H0aLsJdkrRa2dxgQ4kTQHF bytestring-0.11.5.3
    conduit-1.3.6.1-A5CFvWaedHyBbFpBELr7ED
    conduit-extra-1.3.8-4LNkvIzwsWe54JJPbCmwjx containers-0.6.7
    cryptonite-0.30-8l0vgGVIKjy7Czr8tYHBZQ
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    email-validate-2.3.2.21-CqGjuS2PJTaBenHakzPGuf
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    http-client-0.7.19-JFk9tUfcyF3FnWNRzLmEjW
    http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
    http-conduit-2.3.9.1-7x31A8Bvf12J6SDKAlTcxw
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-uri-2.6.4.2-2pvBC2E3r3ZG7itzgqfKfv
    nonce-1.0.7-eVkOmZ8FCS9vuNgFsnqTP
    persistent-2.14.6.1-GEU3f5Qg3bVH7PMKZ9qrSb
    random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    safe-0.3.21-BwgmeaVWtgPGRp7BdJoWxU
    shakespeare-2.2.0-F1BrM1lFfg1FK3grUhK6qH template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    wai-3.2.5-EjZd7LhAo0l7gnL0GV2ALc
    yesod-core-1.6.28.0-CCs8HLnS5Yv6noZUn6dLsQ
    yesod-form-1.7.9.3-JAq53NfyckY5I0PrKoj4Bw
    yesod-persistent-1.6.0.8-2Wxy4pHKc1zKSl05Hbh1B0

haddock-interfaces:   /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html:         /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

